package org.me.web.system.department.controller;

import java.util.ArrayList;
import java.util.List;

import javax.annotation.Resource;

import org.apache.log4j.Logger;
import org.me.core.common.Resoult;
import org.me.core.common.base.BaseController;
import org.me.core.exception.ViewExecption;
import org.me.plugin.ztree.dto.ZtreeDTO;
import org.me.web.system.department.entity.Department;
import org.me.web.system.department.service.IDepartmentService;
import org.springframework.stereotype.Controller;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

@Controller
@RequestMapping("/system/department/")
public class DepartmentController extends BaseController {
	private Logger log = Logger.getLogger(DepartmentController.class);
	@Resource
	private IDepartmentService departmentService;
	
	/**
	 * 查看所有部门
	 * @author: chengbo
	 * @date: 2015年11月23日 15:55:32
	 */
	@RequestMapping("listAllDept")
	@ResponseBody
	public List<ZtreeDTO> listAllDept() {
		List<ZtreeDTO> depts = new ArrayList<>();
		try {
			Department dept = new Department();
			dept.setnState(1);
			depts =toZtree(departmentService.listDept(dept)); 
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e);
			throw new ViewExecption("部门查询失败！");
		}
		return depts;
	}
	
	@RequestMapping("list")
	public ModelAndView list() {
		return new ModelAndView("/system/department/list");
	}
	
	@SuppressWarnings("unchecked")
	@RequestMapping("getDepartmentByPid")
	@ResponseBody
	public List<ZtreeDTO> getDepartmentByPid(String id) {
		List<ZtreeDTO> departments = null;
		if(!StringUtils.hasText(id))
			id = "0";
		try {
			Department d = new Department();
			d.setStrPid(id);
			Resoult r = departmentService.list(d);
			List<Department> list = (ArrayList<Department>) r.getObject();
			departments = toZtree(list);
		} catch (Exception e) {
			e.printStackTrace();
			throw new ViewExecption("部门查询失败！");
		}
		return departments;
	}
	
	@RequestMapping("delById")
	@ResponseBody
	public Resoult delById(String id) {
		Resoult resoult = new Resoult();
		resoult.setName("DepartmentController.delById");
		if(!StringUtils.hasText(id)){
			return resoult; 
		}
		try {
			resoult = departmentService.delById(id);
		} catch (Exception e) {
			e.printStackTrace();
			resoult.setCode(-1);
			resoult.setInfo(e.getMessage());
		}
		return resoult;
	}
	
	@RequestMapping("updateDeptName")
	@ResponseBody
	public Resoult updateDeptName(String id,String name) {
		Resoult resoult = new Resoult();
		resoult.setName("DepartmentController.updateDeptName");
		if(!StringUtils.hasText(id) || !StringUtils.hasText(name))
			return resoult; 
		try {
			resoult = departmentService.updateDeptName(id, name);
		} catch (Exception e) {
			e.printStackTrace();
			resoult.setCode(-1);
			resoult.setInfo(e.getMessage());
		}
		return resoult; 
	}
	
	@RequestMapping("edit")
	public ModelAndView edit(String id) {
		ModelAndView mav = new ModelAndView("/system/department/edit");
		try {
			Resoult r = departmentService.get(id);
			if(r.getObject() != null)
				mav.addObject("department", r.getObject());
		} catch (Exception e) {
			e.printStackTrace();
			throw new ViewExecption("部门查询失败！");
		}
		return mav;
	}
	
	@RequestMapping("saveOrUpdate")
	public ModelAndView saveOrUpdate(Department d) {
		ModelAndView mav = new ModelAndView("/system/department/edit");
		String id = d.getStrId();
		try {
			if(!StringUtils.hasText(id)){
				d.setStrPid("0");
				Resoult resoult = departmentService.save(d);
				d = (Department) resoult.getObject();
			}else {
				departmentService.update(d);
			}
			mav.addObject("department", d);
		} catch (Exception e) {
			e.printStackTrace();
			throw new ViewExecption("修改失败！");
		}
		return mav;
	}
	
	@RequestMapping("addDept")
	@ResponseBody
	public Resoult addDept(String pid,String name) {
		Resoult resoult = new Resoult();
		resoult.setName("DepartmentController.addDept");
		try {
			departmentService.addDept(pid, name);
		} catch (Exception e) {
			e.printStackTrace();
			resoult.setCode(-1);
			resoult.setInfo(e.getMessage());
		}
		return resoult; 
	}
	
	
	/**
	 * 转为ztree数据
	 * @param: list
	 * @author: chengbo
	 * @date: 2015年11月3日 14:56:04
	 */
	private List<ZtreeDTO> toZtree(List<Department> list) {
		List<ZtreeDTO> ztrees = new ArrayList<>();
		for (Department dept : list) {
			ZtreeDTO ztree = new ZtreeDTO();
			ztree.setId(dept.getStrId());
			ztree.setpId(dept.getStrPid());
			ztree.setName(dept.getStrName());
			int hasChild = dept.getnHasChild();
			if(hasChild > 0){
				ztree.setIsParent(true);
			}
			ztrees.add(ztree);
		}
		return ztrees;
	}
}
