package org.me.web.system.department.service.impl;

import java.util.Date;
import java.util.List;
import javax.annotation.Resource;
import org.apache.log4j.Logger;
import org.me.core.common.Resoult;
import org.me.core.exception.ServiceExecption;
import org.me.plugin.util.Uuid;
import org.me.web.system.department.dao.IDepartmentDao;
import org.me.web.system.department.entity.Department;
import org.me.web.system.department.service.IDepartmentService;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

@Service
public class DepartmentService implements IDepartmentService {
	private Logger logger = Logger.getLogger(DepartmentService.class);
	
	@Resource
	private IDepartmentDao departmentDao;
	
	/**
	 * 查询部门
	 * @author: chengbo
	 * @date: 2015年11月23日 15:26:23
	 */
	@Override
	public List<Department> listDept(Department dept) {
		return departmentDao.list(dept);
	}

	@Override
	public Resoult get(String id) {
		Resoult resoult=new Resoult();
		resoult.setName("DepartmentService.get");
		try {
			Department d = departmentDao.get(id);
			resoult.setObject(d);
		} catch (Exception e) {
			e.printStackTrace();
			logger.error(e);
			throw new ServiceExecption("部门获取失败！");
		}
		return resoult;
	}

	@Override
	public Resoult del(List<String> ids) {
		Resoult resoult=new Resoult();
		resoult.setName("DepartmentService.del");
		try {
			for (String id : ids) {
				delById(id);
			}
		} catch (Exception e) {
			e.printStackTrace();
			logger.error(e);
			throw new ServiceExecption("部门删除失败！");
		}
		return resoult;
	}
	
	@Override
	public Resoult delById(String id) {
		Resoult resoult=new Resoult();
		resoult.setName("DepartmentService.delById");
		
		try {
			Department d = departmentDao.get(id);

			/**
			 * 删除其下子部门
			 */
			departmentDao.delByLevel(d.getStrLevel());
			
			/**
			 * 更新父部门子节点状态
			 */
			String pId = d.getStrPid();
			Department pd = departmentDao.get(pId);
			if(pd != null){
				int i = pd.getnHasChild();
				if(i > 0){
					i = i-1;
				}
				pd.setnHasChild(i);
				update(pd);
			}
		} catch (Exception e) {
			e.printStackTrace();
			logger.error(e);
			throw new ServiceExecption("部门修改失败！");
		}
		return resoult;
	}

	@Override
	public Resoult updateDeptName(String id, String name) {
		Resoult resoult=new Resoult();
		resoult.setName("DepartmentService.updateDeptName");
		
		if(!StringUtils.hasText(id)){
			resoult.setCode(-1);
			resoult.setInfo("部门id不可为空！");
			return resoult;
		}
		
		if(!StringUtils.hasText(name)){
			resoult.setCode(-1);
			resoult.setInfo("部门名称不可为空！");
			return resoult;
		}
		
		try {
			Department d = departmentDao.get(id);
			d.setStrName(name);
			resoult = update(d);
		} catch (Exception e) {
			e.printStackTrace();
			logger.error(e);
			throw new ServiceExecption("部门名称修改失败！");
		}
		return resoult;
	}
	
	@Override
	public Resoult update(Department d) {
		Resoult resoult=new Resoult();
		resoult.setName("DepartmentService.update");
		
		if(d == null){
			resoult.setCode(-1);
			resoult.setInfo("暂无此部门！");
			return resoult;
		}
		
		try {
			departmentDao.update(d);
		} catch (Exception e) {
			e.printStackTrace();
			logger.error(e);
			throw new ServiceExecption("部门修改失败！");
		}
		return resoult;
	}
	
	@Override
	public Resoult list(Department t) {
		Resoult resoult=new Resoult();
		resoult.setName("DepartmentService.list");
		try {
			resoult.setObject(departmentDao.list(t));
		} catch (Exception e) {
			e.printStackTrace();
			logger.error(e);
			throw new ServiceExecption("部门查询失败！");
		}
		return resoult;
	}
	
	@Override
	public Resoult addDept(String pid, String name) {
		Resoult resoult=new Resoult();
		resoult.setName("DepartmentService.addDept");
		resoult.setCode(-1);
		
		Department d = new Department();
		d.setStrPid(pid);
		d.setStrName(name);
		
		resoult = save(d);
		return resoult;
	}

	@Override
	public Resoult save(Department d) {
		Resoult resoult=new Resoult();
		resoult.setName("DepartmentService.save");
		
		String pid = d.getStrPid();
		String name = d.getStrName();
		
		if(!StringUtils.hasText(pid) || !StringUtils.hasText(name)){
			resoult.setInfo("名称不可为空!");
			return resoult;
		}
		
		try {
			d.setStrId(new Uuid().getUUID());
			d.setnState(1);
			d.setDtCreateTime(new Date());
			d.setnHasChild(0);
			
			Department pDept = (Department) get(pid).getObject();
			if(pDept == null){
				d.setStrLevel("0");
			}else {
				if(pDept.getnHasChild() <= 0){
					d.setStrLevel(pDept.getStrLevel()+"000");
					pDept.setnHasChild(1);
					update(pDept);
				}else {
					int maxLevel = departmentDao.getMaxLevel(pDept.getStrLevel());
					int level = maxLevel+1;
					String newLevel = "";
					if(level < 10){
						newLevel = "00"+level;
					}else if (level < 100) {
						newLevel = "0"+level;
					}else {
						newLevel = level+"";
					}
					d.setStrLevel(pDept.getStrLevel()+newLevel);
				}
			}
			resoult.setObject(d);
			departmentDao.save(d);
		} catch (Exception e) {
			e.printStackTrace();
			logger.error(e);
			throw new ServiceExecption("部门保存失败！");
		}
		resoult.setInfo("部门保存成功！");
		logger.debug("DepartmentService.save successful!");
		return resoult;
	}
	
}
